MacOSInstallLocationStatus class

Native macOS install-location status.

Constructors

MacOSInstallLocationStatus({required MacOSInstallLocationKind kind, required String? bundlePath, required String? targetPath})
Creates install-location status.
const
MacOSInstallLocationStatus.fromJson(Map<String, Object?> json)
Parses status returned by the native helper.
factory

Properties

bundlePath → String?
Current app bundle path, when known.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → MacOSInstallLocationKind
Install-location category.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldOfferMovePrompt → bool
Whether an app may reasonably offer the Move to Applications prompt.
no setter
targetPath → String?
Preferred /Applications/<App>.app target path, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited