ReleaseInstall class

Install metadata for a staged release artifact.

Constructors

ReleaseInstall({required String strategy, ReleaseInnoInstall? inno, ReleaseMacOSDmgInstall? macosDmg, ReleaseMacOSPkgInstall? macosPkg})
Creates install metadata with the requested strategy.
const
ReleaseInstall.fromJson(Map<String, dynamic> json)
Parses install metadata from the descriptor install object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inno ReleaseInnoInstall?
Windows Inno Setup installer execution metadata.
final
macosDmg ReleaseMacOSDmgInstall?
macOS DMG update metadata.
final
macosPkg ReleaseMacOSPkgInstall?
macOS PKG installer metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strategy String
Native helper strategy used to install the staged artifact.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this install metadata to descriptor JSON.
toString() String
A string representation of this object.
inherited
validate({String? platform, String? artifactKind}) → void
Validates that an install strategy is present.

Operators

operator ==(Object other) bool
The equality operator.
inherited