backupRestoredByNativeHelper property
Whether the native helper reported restoring a backup during rollback.
Implementation
final bool? backupRestoredByNativeHelper;
Whether the native helper reported restoring a backup during rollback.
final bool? backupRestoredByNativeHelper;