UpdateProgress class

Class to represent the progress of the update.

Constructors

UpdateProgress({required double totalBytes, required double receivedBytes, required String currentFile, required int totalFiles, required int completedFiles, String? stagingDirectory})

Properties

completedFiles int
final
currentFile String
final
fraction double
no setter
hashCode int
The hash code for this object.
no setterinherited
receivedBytes double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stagingDirectory String?
final
totalBytes double
final
totalFiles int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited