UpdateReadyToInstall class final

The update artifact has been staged and can be installed.

Inheritance

Constructors

UpdateReadyToInstall({required String stagingPath, bool mandatory = false})
Creates a ready-to-install state for stagingPath.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mandatory bool
Whether the staged update should still be treated as mandatory.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stagingPath String
Platform-specific path passed to the native install helper.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited