UpdateRecoveryStore class abstract interface

App-owned persistence adapter for pending native install recovery markers.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPendingInstall({required String channel}) Future<void>
Clears the pending install marker for channel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPendingInstall({required String channel}) Future<UpdateInstallRecoveryMarker?>
Reads a pending install marker for channel, when one exists.
toString() String
A string representation of this object.
inherited
writePendingInstall(UpdateInstallRecoveryMarker marker) Future<void>
Writes a pending install marker.

Operators

operator ==(Object other) bool
The equality operator.
inherited