AtomicAfterExitNativeInstallRecovery class final
Recovery capability for helpers that must resolve recovery after caller exit.
- Inheritance
-
- Object
- NativeInstallRecovery
- AtomicAfterExitNativeInstallRecovery
Constructors
- AtomicAfterExitNativeInstallRecovery({required NativeInstallStatusOperation query, required NativeInstallStatusOperation resolveAfterExit})
-
Creates an atomic after-exit native recovery capability.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInstallTransaction(
String transactionId) → Future< NativeInstallTransactionStatus?> -
Queries authenticated native helper status for
transactionId.override -
resolvePendingInstallTransactionAfterExit(
String transactionId) → Future< NativeInstallTransactionStatus?> - Resolves a pending install transaction in one exit-bound exchange.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited