QueryAndRecoverNativeInstallRecovery class final

Recovery capability for helpers that support read-only query plus recover.

Inheritance

Constructors

QueryAndRecoverNativeInstallRecovery({required NativeInstallStatusOperation query, required NativeInstallStatusOperation recover})
Creates a query/recover native recovery capability.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryInstallTransaction(String transactionId) Future<NativeInstallTransactionStatus?>
Queries authenticated native helper status for transactionId.
override
recoverPendingInstallTransaction(String transactionId) Future<NativeInstallTransactionStatus?>
Requests helper-owned recovery for transactionId.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited