appName property
String?
get
appName
Name of the app from the active release descriptor, when available.
Implementation
String? get appName => _activeDescriptor?.appName;
Name of the app from the active release descriptor, when available.
String? get appName => _activeDescriptor?.appName;