restartApp method
Hands the staged update to the native installer or restart helper.
Implementation
Future<void> restartApp() async {
_beginInstallAttempt();
try {
await _restartApp();
} finally {
_endInstallAttempt();
}
}
Hands the staged update to the native installer or restart helper.
Future<void> restartApp() async {
_beginInstallAttempt();
try {
await _restartApp();
} finally {
_endInstallAttempt();
}
}