skipUpdate property
bool
get
skipUpdate
Whether the user has skipped the currently offered update in this session.
Implementation
bool get skipUpdate => _skipUpdate;
Whether the user has skipped the currently offered update in this session.
bool get skipUpdate => _skipUpdate;