UpdateTelemetryEvent class
App-consumable telemetry payload for updater lifecycle events.
Constructors
- UpdateTelemetryEvent({required UpdateTelemetryEventType type, String? version, String? channel, String? platform, Uri? source, String? stagingPath, bool? mandatory, Object? error})
-
Creates a telemetry event.
const
- UpdateTelemetryEvent.artifactVerified({Uri? source, String? version, String? channel, String? platform})
-
Creates an artifact-verified event.
const
- UpdateTelemetryEvent.checkFailed({Uri? source, String? channel, Object? error})
-
Creates a check-failed event.
const
- UpdateTelemetryEvent.checkStarted({Uri? source, String? channel})
-
Creates a check-started event.
const
- UpdateTelemetryEvent.downloadFailed({Uri? source, String? version, String? channel, String? platform, Object? error})
-
Creates a download-failed event.
const
- UpdateTelemetryEvent.downloadStarted({Uri? source, String? version, String? channel, String? platform})
-
Creates a download-started event.
const
- UpdateTelemetryEvent.installFailed({String? stagingPath, String? version, String? channel, String? platform, Object? error})
-
Creates an install-failed event.
const
- UpdateTelemetryEvent.installScheduled({String? stagingPath, String? version, String? channel, String? platform})
-
Creates an install-scheduled event.
const
- UpdateTelemetryEvent.updateSelected({String? version, String? channel, String? platform, bool? mandatory})
-
Creates an update-selected event.
const
Properties
- channel → String?
-
Release channel associated with the event, when known.
final
- error → Object?
-
Failure object associated with failed events, when known.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mandatory → bool?
-
Whether the selected update is mandatory, when known.
final
- platform → String?
-
Platform associated with the event, when known.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → Uri?
-
Network or file source associated with the event, when known.
final
- stagingPath → String?
-
Staged update path associated with install events, when known.
final
- type → UpdateTelemetryEventType
-
Event kind.
final
- version → String?
-
Release version associated with the event, when known.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited