UpdateTelemetryEventType enum
Typed update telemetry event names emitted by the updater.
Values
- checkStarted → const UpdateTelemetryEventType
-
An update check started.
- checkFailed → const UpdateTelemetryEventType
-
An update check failed.
- updateSelected → const UpdateTelemetryEventType
-
A newer update was selected.
- downloadStarted → const UpdateTelemetryEventType
-
Artifact download started.
- downloadFailed → const UpdateTelemetryEventType
-
Artifact download failed.
- artifactVerified → const UpdateTelemetryEventType
-
Artifact checksum and descriptor policy verification completed.
- installScheduled → const UpdateTelemetryEventType
-
Install handoff was scheduled.
- installFailed → const UpdateTelemetryEventType
-
Install handoff failed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UpdateTelemetryEventType> - A constant List of the values in this enum, in order of their declaration.