MandatoryReadyToInstallBehavior enum

Controls mandatory ready-to-install behavior in dialog-based update UI.

Inheritance
Available extensions

Values

promptToSaveFirst → const MandatoryReadyToInstallBehavior

Show a restart confirmation with Save first and Restart.

restartWithoutPrompt → const MandatoryReadyToInstallBehavior

Restart immediately when the user presses the ready-to-install action.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MandatoryReadyToInstallBehavior>
A constant List of the values in this enum, in order of their declaration.