UpdateDialogWidget class

A widget that shows an update dialog.

Inheritance

Constructors

UpdateDialogWidget({Key? key, required DesktopUpdaterController controller, Color? backgroundColor, Color? iconColor, Color? shadowColor, Color? textColor, Color? buttonTextColor, Color? buttonIconColor, MandatoryReadyToInstallBehavior mandatoryReadyToInstallBehavior = MandatoryReadyToInstallBehavior.promptToSaveFirst})
Creates an update dialog widget.
const

Properties

backgroundColor → Color?
The background color of the dialog. if null, it will use Theme.of(context).colorScheme.surfaceContainerHigh,
final
buttonIconColor → Color?
The color of the button icon. if null, it will use Theme.of(context).colorScheme.primary,
final
buttonTextColor → Color?
The color of the button text. if null, it will use Theme.of(context).colorScheme.primary,
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
The color of the icon. if null, it will use Theme.of(context).colorScheme.primary,
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mandatoryReadyToInstallBehavior → MandatoryReadyToInstallBehavior
Dialog behavior after a mandatory update has been staged.
final
notifier → DesktopUpdaterController
The controller for the update dialog.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
The color of the shadow. if null, it will use Theme.of(context).shadowColor,
final
textColor → Color?
The color of the text. if null, it will use Theme.of(context).colorScheme.onSurface,
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited