ManualUpdateCheckFreshInstallRequired class final
A newer release is available but requires a fresh download.
- Inheritance
-
- Object
- ManualUpdateCheckResult
- ManualUpdateCheckFreshInstallRequired
Constructors
- ManualUpdateCheckFreshInstallRequired({required ReleaseDescriptor descriptor, required ReleaseFreshInstall freshInstall, required bool mandatory})
-
Creates a fresh-install manual update-check result.
const
Properties
- descriptor → ReleaseDescriptor
-
The release descriptor selected by the update check.
final
- freshInstall → ReleaseFreshInstall
-
Fresh download policy for the selected release.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mandatory → bool
-
Whether the selected release should block skip/dismiss choices.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited