NativeInstallTransactionResultCode enum
Result code reported by the authenticated native install helper.
Values
- none → const NativeInstallTransactionResultCode
-
No result is available.
- accepted → const NativeInstallTransactionResultCode
-
Commit was accepted.
- succeeded → const NativeInstallTransactionResultCode
-
The transaction succeeded.
- rejected → const NativeInstallTransactionResultCode
-
The helper rejected the request.
-
The packaged authenticated helper endpoint is unavailable.
- authenticationFailed → const NativeInstallTransactionResultCode
-
Helper endpoint authentication failed.
- invalidResponse → const NativeInstallTransactionResultCode
-
The helper response failed protocol validation.
- recoveryRequired → const NativeInstallTransactionResultCode
-
The helper must perform crash recovery.
- relaunchFailure → const NativeInstallTransactionResultCode
-
Installation finished, but the best-effort app relaunch was not durably confirmed and will not be retried automatically.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NativeInstallTransactionResultCode> - A constant List of the values in this enum, in order of their declaration.