UpdateStageResult class final
Result returned after a release artifact has been verified and staged.
Properties
- descriptor → ReleaseDescriptor
-
Descriptor that was downloaded and staged.
final
- generationForDispatch → int
-
Check generation that produced this staged result.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownerTokenForDispatch → Object
-
Opaque client identity that owns this staged result.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stageProvenance → StagedUpdateProvenance
-
Immutable inventory retained with the verified stage state.
final
- stageProvenanceSha256 → String
-
Digest retained by the verified client and required by install helpers.
final
- stagingPath → String
-
Platform-specific path handed to the native install helper.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited