VerifiedNativeInstallRequest class sealed

Opaque typed native install request created only by this library.

Properties

channel String
Expected release channel from signed metadata and durable receipt.
no setter
expectedArtifactSha256 String
Expected artifact SHA-256 from the signed descriptor.
no setter
expectedPackageId String
Expected package identity from signed metadata and durable receipt.
no setter
hashCode int
The hash code for this object.
no setterinherited
platform String
Expected target platform from signed metadata and durable receipt.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stageProvenanceSha256 String
SHA-256 of the retained stage provenance marker.
no setter
stagingPath String
Platform-specific staged artifact path.
no setter
transactionId String
Durable native helper transaction identifier.
no setter
updateBuildNumber int?
Nullable expected update build number from signed metadata and receipt.
no setter
updateVersion String
Expected update version from signed metadata and durable receipt.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited